@@ -6,7 +6,7 @@ no warnings qw( void once uninitialized );
 package Sub::HandlesVia::Toolkit::SubAccessorSmall;
 
 our $AUTHORITY = 'cpan:TOBYINK';
-our $VERSION   = '1.001001';
+our $VERSION   = '1.001002';
 
 use Sub::HandlesVia::Toolkit;
 our @ISA = 'Sub::HandlesVia::Toolkit';
@@ -44,9 +44,6 @@ sub code_generator_for_attribute {
 	my $slot = sub {
 		my $gen = shift;
 		delete local $realattr->{chain};
-		delete local $realattr->{clone};
-		delete local $realattr->{clone_on_write};
-		delete local $realattr->{clone_on_read};
 		$realattr->inline_access($gen->generate_self);
 	};
 	
@@ -55,8 +52,6 @@ sub code_generator_for_attribute {
 	if ( $realattr->has_simple_reader ) {
 		$get = sub {
 			my $gen = shift;
-			delete local $realattr->{clone};
-			delete local $realattr->{clone_on_read};
 			return $realattr->inline_access($gen->generate_self);
 		};
 		$get_is_lvalue = !!1;
@@ -64,8 +59,6 @@ sub code_generator_for_attribute {
 	else {
 		$get = sub {
 			my $gen = shift;
-			delete local $realattr->{clone};
-			delete local $realattr->{clone_on_read};
 			return $realattr->inline_reader( $gen->generate_self );
 		}
 	}
@@ -74,8 +67,6 @@ sub code_generator_for_attribute {
 		$set = sub {
 			my ( $gen, $val ) = @_;
 			delete local $realattr->{chain};
-			delete local $realattr->{clone};
-			delete local $realattr->{clone_on_write};
 			return sprintf('(%s)', $realattr->inline_access_w($gen->generate_self, $val) );
 		};
 	}
@@ -83,8 +74,6 @@ sub code_generator_for_attribute {
 		$set = sub {
 			my ( $gen, $val ) = @_;
 			delete local $realattr->{chain};
-			delete local $realattr->{clone};
-			delete local $realattr->{clone_on_write};
 			return $realattr->inline_writer( $gen->generate_self, $val );
 		};
 	}
